@@ -1,5 +1,5 @@
 if (requireNamespace("testthat", quietly = TRUE)) {
   library(testthat)
-  library(mlr3measures)
+  suppressPackageStartupMessages(library(mlr3measures))
   test_check("mlr3measures")
 }
